# Logo Wallypub

The Wallypub logo is a remixed mashup by Jeremiah Miller. Their source material relies on the [Wallabag logo](https://github.com/wallabag/logo/tree/master) by Maylis Agniel 
and the [Epub logo](https://commons.wikimedia.org/wiki/File:Epub_logo.svg) by Koreller

## Logo Typeface

The Typeface used in the logo is based on [Orbitron](https://www.theleagueofmoveabletype.com/orbitron) from
The League of Moveable Type.

## License 

Free Art License 1.3 (FAL 1.3) [artlibre.org](https://artlibre.org/licence/lal/en/)

